@@ -7,7 +7,8 @@ class MapFilter(admin.SimpleListFilter):
 
     title = _('content type')
     parameter_name = 'content_type__id'
-    content_names = ('age', 'sex', 'activity', 'protocol', 'location')
+    content_names = ('age', 'sex', 'activity', 'protocol', 'location',
+                     'species', 'observer')
 
     def lookups(self, request, model_admin):
         types = ContentType.objects.filter(
