@@ -55,7 +55,7 @@ def find_in_map(model, name):
         obj = Map.objects.get(
             content_type=content_type, name=name).content_object
     except Map.DoesNotExist:
-        message = "There is no entry in Map for the %s with the name %s" % (
+        message = "There is no entry in Map for the %s with the name '%s'" % (
             model, name)
         info = sys.exc_info()
         raise info[0], message, info[2]
@@ -217,25 +217,8 @@ def find_map_location(name):
     return location
 
 
-def observers_for_names(names):
-    """Get the list of Observers for the given names.
-
-    Args:
-        names (list(unicode)): the list of names.
-
-    Returns:
-        list(Observer): the list of Observers for the given names. If there is
-        no Observer for a name then one will be created.
-    """
-    observers = []
-    for name in names:
-        observer, created = observer_for_name(name)
-        observers.append(observer)
-    return observers
-
-
 def observer_for_name(name):
-    """Get the list of Observer for the given names.
+    """Get the Observer for the given name.
 
     Args:
         name (unicode): The name of the Observer.
@@ -245,8 +228,17 @@ def observer_for_name(name):
         it will be created.
     """
     if not name:
-        raise ValueError()
-    return Observer.objects.get_or_create(name=name)
+        raise ValueError("Observer name cannot be blank")
+
+    mapping = Map.objects.filter(
+        content_type=ContentType.objects.get_for_model(Observer),
+        name=name,
+    )
+    if mapping:
+        observer, created = mapping[0].content_object, False
+    else:
+        observer, created = Observer.objects.get_or_create(name=name)
+    return observer, created
 
 
 def find_files(path, extension):
@@ -409,12 +401,13 @@ class Command(BaseCommand):
                     filtered.append((path, values, match))
                 else:
                     self.denormalize_values(values)
-                    messages, created = self.add_or_update_checklist(values)
+                    checklist, created, messages = \
+                        self.add_or_update_checklist(values)
                     if created:
-                        added.append((path, values, messages))
+                        added.append((path, checklist, messages))
                     else:
                         if messages:
-                            updated.append((path, values, messages))
+                            updated.append((path, checklist, messages))
                     os.remove(path)
             except:
                 kind, value, trace = sys.exc_info()
@@ -422,10 +415,11 @@ class Command(BaseCommand):
                 failed.append((path, mark_safe(''.join(error))))
 
         report = render_to_string(self.template, {
-            'filtered': filtered,
-            'added': added,
-            'updated': updated,
+            'filtered': sorted(filtered, key=lambda record: record[1]['date']),
+            'added': sorted(added, key=lambda record: record[1].date),
+            'updated': sorted(updated, key=lambda record: record[1].date),
             'errors': failed,
+            'debug': settings.DEBUG,
         })
 
         if settings.DEBUG:
@@ -461,8 +455,17 @@ class Command(BaseCommand):
             if created:
                 messages.append("Added location: %s" % location.name)
 
-        reporter = observers_for_names([values['source']['submitted_by']])[0]
-        observers = observers_for_names(values['observers']['names'])
+        name = values['source']['submitted_by']
+        reporter, created = observer_for_name(name)
+        if created:
+            messages.append("Added observer: %s" % name)
+
+        observers = []
+        for name in values['observers']['names']:
+            observer, created = observer_for_name(name)
+            observers.append(observer)
+            if created:
+                messages.append("Added observer: %s" % name)
 
         if reporter not in observers:
             observers.append(reporter)
@@ -499,11 +502,6 @@ class Command(BaseCommand):
         checklist.observers.add(*observers)
         checklist._created = created
 
-        if created:
-            messages.append("Added checklist: %s" % checklist)
-        else:
-            messages.append("Updated checklist: %s" % checklist)
-
         self.add_or_update_method(checklist, values.get('protocol', None))
 
         if checklist.entries.exists():
@@ -516,7 +514,7 @@ class Command(BaseCommand):
         for values in values['entries']:
             self.add_or_update_entry(checklist, values, messages)
 
-        return messages, created
+        return checklist, created, messages
 
     def add_or_update_location(self, values):
         params = {
