@@ -13,9 +13,7 @@ name was added. So finalizing the Species table is simply a matter of deleting
 all the records where include remains False.
 """
 
-from checklists.models import Species, set_current_user, clear_current_user
+from checklists.models import Species
 
 def run():
-    set_current_user('load_map')
     Species.objects.filter(include=False).delete()
-    clear_current_user()
