@@ -312,18 +312,6 @@ class FilterChecklistTestCase(TestCase):
         self.assertTrue('Checklists filtered' in sections[1])
         self.assertTrue('Cape Clear' in sections[2])
 
-    def test_status_report_contains_filter_key(self):
-        Filter.objects.create(key='location.name', value='Cape Clear')
-        call_command('load_checklists', dir=self.directory)
-        sections = mail.outbox[0].body.split('+-')
-        self.assertTrue('Matching Filter: %s' % 'location.name' in sections[2])
-
-    def test_status_report_contains_filter_value(self):
-        Filter.objects.create(key='location.name', value='Cape Clear')
-        call_command('load_checklists', dir=self.directory)
-        sections = mail.outbox[0].body.split('+-')
-        self.assertTrue('Matching Value: "%s"' % 'Cape Clear' in sections[2])
-
 
 class CreateChecklistTestCase(TestCase):
 
@@ -541,11 +529,11 @@ class StatusReportTestCase(SimpleTestCase):
 
     def test_no_checklists_were_filtered(self):
         contents = mail.outbox[0].body
-        self.assertFalse('Checklists filtered' in contents)
+        self.assertTrue('No checklists were filtered.' in contents)
 
     def test_no_errors_in_status_report(self):
         contents = mail.outbox[0].body
-        self.assertFalse('Errors' in contents)
+        self.assertTrue('No errors occurred.' in contents)
 
 
 @mock.patch.object(settings, 'CHECKLISTS_REPORT_RECIPIENTS',
